==> epiphany-webapps_0.0.2.tar.xz: epiphany-webapps-0.0.2/README.md <==
# Epiphany web apps _(epiphany-webapps)_

> web apps for GNOME Web

[project] | [code] | [tracker]

Epiphany web apps is a collection of web applications
for use with GNOME Web.

This package contains resources for web apps. Including:

* icons for all web apps and wrappers for web interfaces
* build routines to fetch and optimize icons


## Install

If these web apps are not pre-installed on your system,
then the preferred installation method is your package manager.
Installing each wep app package
will install the desktop file and icon for that web app on your system.

Runtime requirements:

* GNOME Web (a.k.a. Epiphany) 3.19.1 or newer


<!-- TODO: actually release package for Debian

### Debian

On Debian and derived systems (including Ubuntu and PureOS):

```
sudo apt install epiphany-webapps-sm.puri.news
```

Repeat for each web app package.

To list all available web app packages:

```
apt search epiphany-webapps-*
```

-->


### From source tarball

Build requirements when installing from source:

* make
* scour
* rsvg-convert
* gtk-update-icon-cache

Installing from source tarball:

```
./configure
make
sudo make install
```

### From Git snapshot

Additional build requirements when installing from Git snapshot:

* autoconf 2.69 or newer
* autoconf-archive 2015-02-05 or newer
* automake

Installing from Git snapshot:

```
./bootstrap
./configure
make
sudo make install
```

## Configuration

Consult your distribution how to configure when installing a package.


## Usage

* Click on the web app icon to launch.


## Implementation

Web apps are currently implemented as GNOME Web applications,
configured by debconf. See
[How do I define a system-wide web application?](http://wiki.gnome.org/Apps/Web/Docs/FrequentlyAskedQuestions#How_do_I_define_a_system-wide_web_application.3F)
(GNOME Web FAQ) for details.

This implementation should work on any Debian-based distribution that
includes GNOME Web.


## Sharing and contributions

Epiphany web apps  
<https://source.puri.sm/librem5-apps/epiphany-webapps>  
Copyright 2020 Purism SPC  
SPDX-License-Identifier: AGPL-3.0-or-later

Shared under AGPL-3.0-or-later.
We adhere to the Community Covenant 1.0 without modification,
and certify origin per DCO 1.1 with a signed-off-by line.
Contributions under the same terms are welcome.

For details see:

* [COPYING.AGPL.md], full license text
* [CODE_OF_CONDUCT.md], full conduct text
* [CONTRIBUTING.DCO.md], full origin text (`git -s`)

<!-- * [CONTRIBUTING.md], additional contribution notes -->

<!-- Links -->

[project]: https://source.puri.sm/librem5-apps/epiphany-webapps
[code]: https://source.puri.sm/librem5-apps/epiphany-webapps/tree/master
[tracker]: https://source.puri.sm/librem5-apps/epiphany-webapps/issues
[SETUP.md]: SETUP.md
[COPYING.AGPL.md]: COPYING.AGPL.md
[CODE_OF_CONDUCT.md]: CODE_OF_CONDUCT.md
[CONTRIBUTING.DCO.md]: CONTRIBUTING.DCO.md
[COPYING.md]: COPYING.md
[CONTRIBUTING.md]: CONTRIBUTING.md

==> epiphany-webapps_0.0.5.tar.xz: epiphany-webapps-0.0.5/README.md <==
# Epiphany web apps _(epiphany-webapps)_

> web apps for GNOME Web

[project] | [code] | [tracker]

Epiphany web apps is a collection of web applications
for use with GNOME Web.

This package contains resources for web apps. Including:

* icons for all web apps and wrappers for web interfaces
* build routines to fetch and optimize icons


## Install

If these web apps are not pre-installed on your system,
then the preferred installation method is your package manager.
Installing each wep app package
will install the appdata, desktop file and icon for that web app
on your system.

Runtime requirements:

* GNOME Web (a.k.a. Epiphany) 3.19.1 or newer


<!-- TODO: actually release package for Debian

### Debian

On Debian and derived systems (including Ubuntu and PureOS):

```
sudo apt install epiphany-webapps-sm.puri.news
```

Repeat for each web app package.

To list all available web app packages:

```
apt search epiphany-webapps-*
```

-->


### From source tarball

Build requirements when installing from source:

* make
* scour
* rsvg-convert
* gtk-update-icon-cache

Installing from source tarball:

```
./configure
make
sudo make install
```

### From Git snapshot

Additional build requirements when installing from Git snapshot:

* autoconf 2.69 or newer
* autoconf-archive 2015-02-05 or newer
* automake

Installing from Git snapshot:

```
./bootstrap
./configure
make
sudo make install
```

## Configuration

Consult your distribution how to configure when installing a package.


## Usage

* Click on the web app icon to launch.


## Implementation

Web apps are currently implemented as GNOME Web applications,
configured by debconf. See
[How do I define a system-wide web application?](http://wiki.gnome.org/Apps/Web/Docs/FrequentlyAskedQuestions#How_do_I_define_a_system-wide_web_application.3F)
(GNOME Web FAQ) for details.

This implementation should work on any Debian-based distribution that
includes GNOME Web.


## Sharing and contributions

Epiphany web apps  
<https://source.puri.sm/librem5-apps/epiphany-webapps>  
Copyright 2020 Purism SPC  
SPDX-License-Identifier: AGPL-3.0-or-later

Shared under AGPL-3.0-or-later.
We adhere to the Community Covenant 1.0 without modification,
and certify origin per DCO 1.1 with a signed-off-by line.
Contributions under the same terms are welcome.

For details see:

* [COPYING.AGPL.md], full license text
* [CODE_OF_CONDUCT.md], full conduct text
* [CONTRIBUTING.DCO.md], full origin text (`git -s`)

<!-- * [CONTRIBUTING.md], additional contribution notes -->

<!-- Links -->

[project]: https://source.puri.sm/librem5-apps/epiphany-webapps
[code]: https://source.puri.sm/librem5-apps/epiphany-webapps/tree/master
[tracker]: https://source.puri.sm/librem5-apps/epiphany-webapps/issues
[SETUP.md]: SETUP.md
[COPYING.AGPL.md]: COPYING.AGPL.md
[CODE_OF_CONDUCT.md]: CODE_OF_CONDUCT.md
[CONTRIBUTING.DCO.md]: CONTRIBUTING.DCO.md
[COPYING.md]: COPYING.md
[CONTRIBUTING.md]: CONTRIBUTING.md
